# pushy-python

The official [Pushy SDK](https://pushy.me/) for [Python](https://www.python.org/) apps.

> [Pushy](https://pushy.me/) is the most reliable push notification gateway, perfect for real-time, mission-critical applications.

## Usage

Please refer to our [detailed documentation](https://pushy.me/docs/additional-platforms/python) to get started.

## License

[Apache 2.0](LICENSE)